Method: IniFile#eql?

Defined in:
lib/inifile.rb

#eql?(other) ⇒ Boolean Also known as: ==

Public: Compare this IniFile to some other IniFile. For two INI files to be equivalent, they must have the same sections with the same parameter / value pairs in each section.

other - The other IniFile.

Returns true if the INI files are equivalent and false if they differ.

Returns:

  • (Boolean)


389
390
391
392
393
# File 'lib/inifile.rb', line 389

def eql?( other )
  return true if equal? other
  return false unless other.instance_of? self.class
  @ini == other.instance_variable_get(:@ini)
end