Method: IniFile#clone
- Defined in:
- lib/inifile.rb
#clone ⇒ Object
Public: Produces a duplicate of this IniFile. The duplicate is independent of the original – i.e. the duplicate can be modified without changing the original. The tainted state and the frozen state of the original is copied to the duplicate.
Returns a new IniFile.
375 376 377 378 379 |
# File 'lib/inifile.rb', line 375 def clone other = dup other.freeze if self.frozen? other end |